Module types

Module types 

Type definitions and re-exports for client requests and responses.

Structs

AddCollectionRecordsPayload
Payload for adding records to a collection.
AddCollectionRecordsRequest
AddCollectionRecordsResponse
BoolInvertedIndexConfig
BoolInvertedIndexType
BoolValueType
Boolean value type index configurations
ChromaRegex
Chroma custom wrapper for a Regex pattern.
Collection
CollectionConfiguration
CompositeExpression
CountCollectionsRequest
CreateCollectionRequest
DataChunkIteraror
DeleteCollectionRecordsPayload
Payload for deleting records from a collection.
DeleteCollectionRecordsRequest
DeleteCollectionRecordsResponse
DeleteCollectionRequest
DocumentExpression
EmbeddingFunctionNewConfiguration
Filter
Filter the search results.
FloatInvertedIndexConfig
FloatInvertedIndexType
FloatListValueType
Float list value type index configurations (for vectors)
FloatValueType
Float value type index configurations
ForkCollectionRequest
FtsIndexConfig
FtsIndexType
GetRequest
GetResponse
All arrays have the same length, with each index representing a single record. Only fields specified in the request’s include parameter are populated.
GetUserIdentityResponse
GroupBy
Groups results by metadata keys and aggregates within each group.
HeartbeatResponse
HnswConfiguration
HnswIndexConfig
Configuration for HNSW vector index algorithm parameters
IncludeList
IndexStatusResponse
IntInvertedIndexConfig
IntInvertedIndexType
IntValueType
Integer value type index configurations
Limit
Pagination control for search results.
MetadataExpression
QueryRequest
QueryResponse
Rank
Wrapper for ranking expressions in search queries.
Schema
Schema representation for collection index configurations
SearchPayload
A search payload for the hybrid search API.
SearchRequest
SearchResponse
Segment
Select
Field selection for search results.
SpannConfiguration
SpannIndexConfig
Configuration for SPANN vector index algorithm parameters
SparseVector
Represents a sparse vector using parallel arrays for indices and values.
SparseVectorIndexConfig
SparseVectorIndexType
SparseVectorValueType
Sparse vector value type index configurations
StringInvertedIndexConfig
StringInvertedIndexType
StringValueType
String value type index configurations
UpdateCollectionConfiguration
UpdateCollectionRecordsPayload
Payload for updating existing records in a collection.
UpdateCollectionRecordsRequest
UpdateCollectionRecordsResponse
UpdateCollectionRequest
UpdateHnswConfiguration
UpdateSpannConfiguration
UpsertCollectionRecordsPayload
Payload for upserting records in a collection.
UpsertCollectionRecordsRequest
UpsertCollectionRecordsResponse
ValueTypes
Strongly-typed value type configurations Contains optional configurations for each supported value type
VectorIndexConfig
VectorIndexType

Enums

Aggregate
Aggregation function applied within each group.
Base64DecodeError
BooleanOperator
ChromaHir
Chroma custom internal representation for a Regex pattern.
Cmek
Customer-managed encryption key for storage encryption.
CollectionConversionError
CollectionToProtoError
ContainsOperator
DistributedSpannParametersFromSegmentError
DocumentOperator
EmbeddingFunctionConfiguration
ExecutorError
FilterValidationError
FtsAlgorithm
Full-text search index algorithm.
GetCollectionWithSegmentsError
HeartbeatError
HnswParametersFromSegmentError
Include
Use this enum to specify which fields should be returned when retrieving records.
IndexStatusError
Key
Represents a field key in search queries.
MetadataComparison
MetadataSetValue
MetadataValue
PrimitiveOperator
QueryError
QueryVector
A query vector for KNN search.
RankExpr
A ranking expression for scoring and ordering search results.
ReadLevel
ScalarEncoding
SchemaBuilderError
SchemaError
SegmentScopeConversionError
SetOperator
Space
SparseIndexAlgorithm
Sparse vector index algorithm.
UpdateEmbeddingsPayload
UpdateMetadataValue
UpdateTenantError
VectorIndexConfiguration
Where
This Where enum serves as an unified representation for the where and where_document clauses. Although this is not unified in the API level due to legacy design choices, in the future we will be unifying them together, and the structure of the unified AST should be identical to the one here. Currently both where and where_document clauses will be translated into Where, and if both are present we simply create a conjunction of both clauses as the actual filter. This is consistent with the semantics we used to have when the where and where_document clauses are treated seperately.
WhereError

Functions

rrf
Reciprocal Rank Fusion (RRF) - combines multiple ranking strategies.

Type Aliases

Metadata
UpdateMetadata