pub enum ReadLevel {
IndexAndWal,
IndexOnly,
IndexAndBoundedWal,
}Variants
IndexAndWal
Read from both the index and the write-ahead log (default). Provides full consistency with all committed writes visible.
IndexOnly
Read only from the index, skipping the write-ahead log. Provides eventual consistency - recent uncommitted writes may not be visible.
IndexAndBoundedWal
Read from the index and up to a server-configured number of write-ahead log entries. Provides a consistent prefix of the WAL with bounded query latency: recently committed writes beyond the limit may not be visible.